kibitzr.fetcher package
=======================

Submodules
----------

kibitzr.fetcher.browser module
------------------------------

.. automodule:: kibitzr.fetcher.browser
    :members:
    :undoc-members:
    :show-inheritance:

kibitzr.fetcher.simple module
-----------------------------

.. automodule:: kibitzr.fetcher.simple
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: kibitzr.fetcher
    :members:
    :undoc-members:
    :show-inheritance:
